@@ -26,7 +26,7 @@ def cmd():
     elif args[-1] == "query":
         status = os.system("curl http://"+get_ip()+":8080/query")
     else:
-        print("Usage: idscheck [(Null)|gpu|top|topall]")
+        print("Usage: ids [(Null)|gpu|top|topall]")
 
 
 def gpu():
